@@ -13,17 +13,18 @@ This example shows how you can define the grammar of a regular language and how
 to use variables in this grammar with completers and tokens attached.
 """
 from __future__ import unicode_literals
-from prompt_toolkit.completion import WordCompleter
-
-from prompt_toolkit import prompt
-from prompt_toolkit.contrib.regular_languages.compiler import compile
-from prompt_toolkit.contrib.regular_languages.completion import GrammarCompleter
-from prompt_toolkit.contrib.regular_languages.lexer import GrammarLexer
-from prompt_toolkit.lexers import SimpleLexer
-from prompt_toolkit.styles import Style
 
 import math
 
+from prompt_toolkit import prompt
+from prompt_toolkit.completion import WordCompleter
+from prompt_toolkit.contrib.regular_languages.compiler import compile
+from prompt_toolkit.contrib.regular_languages.completion import (
+    GrammarCompleter,
+)
+from prompt_toolkit.contrib.regular_languages.lexer import GrammarLexer
+from prompt_toolkit.lexers import SimpleLexer
+from prompt_toolkit.styles import Style
 
 operators1 = ['add', 'sub', 'div', 'mul']
 operators2 = ['sqrt', 'log', 'sin', 'ln']
